@@ -5,7 +5,7 @@ use warnings;
 package Path::Tiny;
 # ABSTRACT: File path utility
 
-our $VERSION = '0.073'; # TRIAL
+our $VERSION = '0.075'; # TRIAL
 
 # Dependencies
 use Config;
@@ -237,6 +237,7 @@ sub path {
     if ( $path =~ m{^(~[^/]*).*} ) {
         require File::Glob;
         my ($homedir) = File::Glob::bsd_glob($1);
+        $homedir =~ tr[\\][/] if IS_WIN32();
         $path =~ s{^(~[^/]*)}{$homedir};
     }
 
@@ -1787,7 +1788,7 @@ Path::Tiny - File path utility
 
 =head1 VERSION
 
-version 0.073
+version 0.075
 
 =head1 SYNOPSIS
 
@@ -1831,10 +1832,10 @@ version 0.073
 
 =head1 DESCRIPTION
 
-This module provide a small, fast utility for working with file paths.  It is
+This module provides a small, fast utility for working with file paths.  It is
 friendlier to use than L<File::Spec> and provides easy access to functions from
 several other core file handling modules.  It aims to be smaller and faster
-than many alternatives on CPAN while helping people do many common things in
+than many alternatives on CPAN, while helping people do many common things in
 consistent and less error-prone ways.
 
 Path::Tiny does not try to work for anything except Unix-like and Win32
@@ -2793,7 +2794,7 @@ David Golden <dagolden@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alex Efros Chris Williams David Golden Steinbrunner Doug Bell Gabor Szabo Gabriel Andrade George Hartzell Geraud Continsouzas Goro Fuji Graham Knop James Hunt Karen Etheridge Mark Ellis Martin Kjeldsen Michael G. Schwern Philippe Bruhat (BooK) Regina Verbae Smylers Tatsuhiko Miyagawa Toby Inkster Yanick Champoux 김도형 - Keedi Kim
+=for stopwords Alex Efros Chris Williams David Golden Steinbrunner Doug Bell Gabor Szabo Gabriel Andrade George Hartzell Geraud Continsouzas Goro Fuji Graham Knop James Hunt Karen Etheridge Mark Ellis Martin Kjeldsen Michael G. Schwern Philippe Bruhat (BooK) Regina Verbae Roy Ivy III Shlomi Fish Smylers Tatsuhiko Miyagawa Toby Inkster Yanick Champoux 김도형 - Keedi Kim
 
 =over 4
 
@@ -2871,6 +2872,14 @@ Regina Verbae <regina-verbae@users.noreply.github.com>
 
 =item *
 
+Roy Ivy III <RIVY.dev@gmail.com>
+
+=item *
+
+Shlomi Fish <shlomif@shlomifish.org>
+
+=item *
+
 Smylers <Smylers@stripey.com>
 
 =item *
